#include "iostream.h"
#include "fstream.h"
#include "TChain.h"
#include "TH1.h"
#include "TSystem.h"
#include "TFile.h"

//
// Creates a chain of a sample of BB_Sample trees from background
// events (typically 1000 files/directory) and builds histograms...
//
void CombineTest(const char *outlog="Combine.log", 
		 Int_t firstfile=2546, const char *base="./") {
  Int_t nfiles=4;
  //
  // log of missing files (and what else)
  ofstream log(outlog);
  if (!log) {cerr<<"Unable to open log file!"<<endl; return;}
  log<<"List of zombie or tree-missing files:"<<endl;
  //
  TChain chain("BB_Sample");
  Bool_t nonce=0;
  TString nomein;
  TFile *provaop;
  //  TTree *albero;
  Int_t nmiss=0;
  char *ptof="AliSelectSampleBBc1.%d.root";
  for (Int_t k=firstfile; k<=(firstfile+nfiles-1) ; k++) {
    char*prv=new char[50];
    sprintf(prv,ptof,k);
    nomein=base;
    nomein+=prv;
    nonce=gSystem->AccessPathName(nomein.Data(),kFileExists);
    if (nonce) {nmiss++; continue;}
    provaop=new TFile(nomein.Data());
    if (provaop->IsZombie()) {log<<nomein.Data()<<endl; continue;}
    TTree *albero=(TTree *)gROOT->FindObject("BB_Sample"); cout<<k<<"  albero "<<albero<<endl;
    if (!albero) {log<<nomein.Data()<<endl; cout<<nomein.Data()<<endl; continue;}
    delete albero;
    if (provaop) {provaop->Close();}
    chain.Add(nomein.Data());
    delete prv;
  }
//Declaration of leaves types
  struct CandidateB {
    Int_t   evnum;
    Int_t   lab;  
    Int_t   pdg;  
    Int_t   proc; 
    Int_t   pdgmum;
    Int_t   npttr;
    Float_t pxmea;
    Float_t pymea;
    Float_t pzmea;
    Float_t pxori;
    Float_t pyori;
    Float_t pzori;
    Float_t pxmum;
    Float_t pymum;
    Float_t pzmum;
    Float_t d0bpl;
    Float_t vertx;
    Float_t verty;
    Float_t vertz;
    Float_t zovtx;
  };
  
//Set branch address
  CandidateB myp;
  chain.SetBranchAddress("bcand",&myp);
//Loop over entries
   Int_t nentries = (Int_t)chain.GetEntries();
   printf("Total number of entries in chain = %d\n",nentries);
   Int_t nbytes=0, savevnum=0, nreadev=0;
   for (Int_t i=0; i<nentries;i++) {
     if(i % 20000 ==0) cout<<" analysed: "<<i<<" entries \r";
     nbytes += chain.GetEvent(i);
     if (myp.evnum>savevnum) { nreadev++; savevnum=myp.evnum;}
   }
   cout<<endl;
   log<<" Total of "<<nmiss<<" missing files, "<<nfiles-nmiss<<" files analysed"<<endl;
   log<<"Total number of entries in chain: \n"<<nentries<<endl;
   log<<"Total number of physical events in chain: \n"<<nreadev<<endl;
   log.close();
}
